@@ -32,48 +32,47 @@ __all__ = [
 
 
 #: HTTP/1.1 status codes as listed in http://www.ietf.org/rfc/rfc2616.txt
-HTTP_STATUS_CODES = {
-      100: 'Continue',
-      101: 'Switching Protocols',
-      200: 'OK',
-      201: 'Created',
-      202: 'Accepted',
-      203: 'Non-Authoritative Information',
-      204: 'No Content',
-      205: 'Reset Content',
-      206: 'Partial Content',
-      300: 'Multiple Choices',
-      301: 'Moved Permanently',
-      302: 'Found',
-      303: 'See Other',
-      304: 'Not Modified',
-      305: 'Use Proxy',
-      307: 'Temporary Redirect',
-      400: 'Bad Request',
-      401: 'Unauthorized',
-      402: 'Payment Required',
-      403: 'Forbidden',
-      404: 'Not Found',
-      405: 'Method Not Allowed',
-      406: 'Not Acceptable',
-      407: 'Proxy Authentication Required',
-      408: 'Request Time-out',
-      409: 'Conflict',
-      410: 'Gone',
-      411: 'Length Required',
-      412: 'Precondition Failed',
-      413: 'Request Entity Too Large',
-      414: 'Request-URI Too Large',
-      415: 'Unsupported Media Type',
-      416: 'Requested range not satisfiable',
-      417: 'Expectation Failed',
-      500: 'Internal Server Error',
-      501: 'Not Implemented',
-      502: 'Bad Gateway',
-      503: 'Service Unavailable',
-      504: 'Gateway Time-out',
-      505: 'HTTP Version not supported',
-}
+HTTP_STATUS_CODES = {100: 'Continue',
+                     101: 'Switching Protocols',
+                     200: 'OK',
+                     201: 'Created',
+                     202: 'Accepted',
+                     203: 'Non-Authoritative Information',
+                     204: 'No Content',
+                     205: 'Reset Content',
+                     206: 'Partial Content',
+                     300: 'Multiple Choices',
+                     301: 'Moved Permanently',
+                     302: 'Found',
+                     303: 'See Other',
+                     304: 'Not Modified',
+                     305: 'Use Proxy',
+                     307: 'Temporary Redirect',
+                     400: 'Bad Request',
+                     401: 'Unauthorized',
+                     402: 'Payment Required',
+                     403: 'Forbidden',
+                     404: 'Not Found',
+                     405: 'Method Not Allowed',
+                     406: 'Not Acceptable',
+                     407: 'Proxy Authentication Required',
+                     408: 'Request Time-out',
+                     409: 'Conflict',
+                     410: 'Gone',
+                     411: 'Length Required',
+                     412: 'Precondition Failed',
+                     413: 'Request Entity Too Large',
+                     414: 'Request-URI Too Large',
+                     415: 'Unsupported Media Type',
+                     416: 'Requested range not satisfiable',
+                     417: 'Expectation Failed',
+                     500: 'Internal Server Error',
+                     501: 'Not Implemented',
+                     502: 'Bad Gateway',
+                     503: 'Service Unavailable',
+                     504: 'Gateway Time-out',
+                     505: 'HTTP Version not supported',
+                     }
 
 # Symbolic names for the HTTP status codes
 STATUS_CONTINUE = 100
@@ -647,20 +646,19 @@ class Response(object):
         return cls(
             status=STATUS_REQUEST_ENTITY_TOO_LARGE,
             content=["<html>"
-                "<body>"
-                    "<h1>Request Entity Too Large</h1>"
-                "</body>"
-                "</html>"
-            ]
-        )
+                     "<body>"
+                     "<h1>Request Entity Too Large</h1>"
+                     "</body>"
+                     "</html>"])
 
     @classmethod
     def method_not_allowed(cls, valid_methods):
         """\
         Return an HTTP method not allowed response (405)::
 
+            >>> from fresco import context
             >>> def view():
-            ...     if request.method == 'POST':
+            ...     if context.request.method == 'POST':
             ...         return Response.method_not_allowed(('POST', ))
             ...
 
@@ -673,12 +671,11 @@ class Response(object):
             status=STATUS_METHOD_NOT_ALLOWED,
             allow=",".join(valid_methods),
             content=["<html>"
-                "<body>"
-                    "<h1>Method not allowed</h1>"
-                "</body>"
-                "</html>"
-            ]
-        )
+                     "<body>"
+                     "<h1>Method not allowed</h1>"
+                     "</body>"
+                     "</html>"
+                     ])
 
     @classmethod
     def internal_server_error(cls):
@@ -696,14 +693,12 @@ class Response(object):
 
         return cls(
             status=STATUS_INTERNAL_SERVER_ERROR,
-            content=[
-                "<html>"
-                "<body>"
-                "<h1>Internal Server Error</h1>"
-                "</body>"
-                "</html>"
-            ]
-        )
+            content=["<html>"
+                     "<body>"
+                     "<h1>Internal Server Error</h1>"
+                     "</body>"
+                     "</html>"
+                    ])
 
     @classmethod
     def redirect(cls, location, request=None, status=STATUS_FOUND):
