@@ -1,16 +1,17 @@
+import pytest
 from flea import TestAgent
-from nose.tools import assert_equal, assert_raises
 
 from fresco import FrescoApp, GET, Response
 from fresco.requestcontext import RequestContext
 
+
 class TestRequestContext(object):
 
     def test_instantiation(self):
         """
         Can we cleanly instantiate a RequestContext object?
         """
-        s = RequestContext()
+        RequestContext()
 
     def test_app_populates_request_object(self):
 
@@ -22,7 +23,7 @@ class TestRequestContext(object):
         app = FrescoApp()
         app.route('/', GET, view)
 
-        assert_equal(TestAgent(app).get('/').body, '')
+        assert TestAgent(app).get('/').body == ''
 
     def test_context_returns_correct_request_for_each_app(self):
 
@@ -38,6 +39,7 @@ class TestRequestContext(object):
         def view():
             from fresco.core import context
             request_id = id(context.request)
+
             def generate_response():
                 for i in range(itercount):
                     assert id(context.request) == request_id
@@ -60,29 +62,30 @@ class TestRequestContext(object):
             t.join()
 
         # Check that threaded requests were genuinely interleaved
-        for i1, i2 in zip(output[:itercount-1], output[1:itercount]):
+        for i1, i2 in zip(output[:itercount - 1], output[1:itercount]):
             if i1[:2] != i2[:2]:
                 break
         else:
             raise AssertionError("Output does not appear interleaved")
-        assert_equal(len(output), threadcount * itercount)
+        assert len(output), threadcount * itercount
 
     def test_context_does_not_inherit_from_parent(self):
         c = RequestContext()
         c.push(foo=1)
         c.push(bar=2)
-        assert_raises(AttributeError, lambda: c.foo)
+        with pytest.raises(AttributeError):
+            c.foo
 
     def test_child_context_overrides_parent(self):
         c = RequestContext()
         c.push(foo=1)
         c.push(foo=2)
-        assert_equal(c.foo, 2)
+        assert c.foo == 2
 
     def test_pop_context_removes_keys(self):
         c = RequestContext()
         c.push(foo=1)
         c.push(foo=2)
-        assert_equal(c.foo, 2)
+        assert c.foo == 2
         c.pop()
-        assert_equal(c.foo, 1)
+        assert c.foo == 1
