@@ -5,7 +5,6 @@
 from __future__ import unicode_literals
 from io import BytesIO
 
-from nose.tools import assert_equal
 from flea import TestAgent
 
 from fresco.compat import quote
@@ -22,25 +21,25 @@ class TestParseQueryString(object):
         return list(parse_querystring(value))
 
     def test_empty(self):
-        assert_equal(self.p(''), [])
+        self.p('') == []
 
     def test_simple_key_value(self):
-        assert_equal(self.p('a=b'), [('a', 'b')])
+        assert self.p('a=b') == [('a', 'b')]
 
     def test_key_with_space(self):
-        assert_equal(self.p('a+b=c'), [('a b', 'c')])
+        assert self.p('a+b=c') == [('a b', 'c')]
 
     def test_value_with_space(self):
-        assert_equal(self.p('a=b+c'), [('a', 'b c')])
+        assert self.p('a=b+c') == [('a', 'b c')]
 
     def test_double_equals(self):
-        assert_equal(self.p('a==b'), [('a', '=b')])
+        assert self.p('a==b') == [('a', '=b')]
 
     def test_escaped_chars(self):
-        assert_equal(self.p('%20==c%3D'), [(' ', '=c=')])
+        assert self.p('%20==c%3D') == [(' ', '=c=')]
 
     def test_charset(self):
-        assert_equal(self.p('a=el%20ni%C3%B1o'), [('a', 'el niño')])
+        assert self.p('a=el%20ni%C3%B1o') == [('a', 'el niño')]
 
 
 class TestParseMultipart(object):
@@ -55,24 +54,21 @@ class TestParseMultipart(object):
             }
             parsed = sorted(list(parse_post(environ, io, 'UTF-8')))
 
-            assert_equal(
-                [name for name, value in parsed],
-                ["empty-text-input", "file-upload", "text-input-ascii",
-                "text-input-unicode"]
-            )
+            assert [name for name, value in parsed] == \
+["empty-text-input", "file-upload", "text-input-ascii", "text-input-unicode"]
 
-            assert_equal(parsed[0], ("empty-text-input", ""))
-            assert_equal(parsed[2], ("text-input-ascii", "abcdef"))
-            assert_equal(parsed[3], ("text-input-unicode",
-                                    b"\xce\xb1\xce\xb2\xce\xb3\xce\xb4"\
-                                    .decode("utf8")))
+            assert parsed[0] == ("empty-text-input", "")
+            assert parsed[2] == ("text-input-ascii", "abcdef")
+            assert parsed[3] == ("text-input-unicode",
+                                    b"\xce\xb1\xce\xb2\xce\xb3\xce\xb4"
+                                    .decode("utf8"))
 
             fieldname, fileupload = parsed[1]
-            assert_equal(fieldname, "file-upload")
-            assert_equal(fileupload.filename, "test.data")
-            assert_equal(fileupload.headers['content-type'],
-                        "application/octet-stream")
-            assert_equal(fileupload.file.read(), form_data.FILE_UPLOAD_DATA)
+            assert fieldname == "file-upload"
+            assert fileupload.filename == "test.data"
+            assert fileupload.headers['content-type'] == \
+                        "application/octet-stream"
+            assert fileupload.file.read() == form_data.FILE_UPLOAD_DATA
 
     def test_fileupload_too_big(self):
         """\
@@ -92,14 +88,14 @@ class TestParseMultipart(object):
             files=[('f1', 'filename.txt', 'text/plain', 'x' * 1000)],
             check_status=False
         )
-        assert_equal(r.response.status, "413 Request Entity Too Large")
+        assert r.response.status == "413 Request Entity Too Large"
 
         r = TestAgent(app).post_multipart(
             files=[('f1', 'filename.txt', 'text/plain', 'x' * 400)],
             data={'f2': 'x' * 101},
             check_status=False
         )
-        assert_equal(r.response.status, "413 Request Entity Too Large")
+        assert r.response.status == "413 Request Entity Too Large"
 
     def test_fileupload_with_invalid_content_length(self):
 
@@ -116,7 +112,7 @@ class TestParseMultipart(object):
             CONTENT_LENGTH=unicode_to_environ("499"),
             check_status=False
         )
-        assert_equal(r.response.status, "400 Bad Request")
+        assert r.response.status == "400 Bad Request"
 
     def test_multipart_field_too_big(self):
         """
@@ -134,7 +130,7 @@ class TestParseMultipart(object):
 
         r = TestAgent(app).post_multipart(data=[('f1', 'x' * 200)],
                                           check_status=False)
-        assert_equal(r.response.status, "413 Request Entity Too Large")
+        assert r.response.status == "413 Request Entity Too Large"
 
 
 class TestParseFormEncodedData(object):
@@ -159,7 +155,7 @@ class TestParseFormEncodedData(object):
         app.route('/', POST, view)
 
         r = TestAgent(app).post(data=[('f1', 'x' * 200)], check_status=False)
-        assert_equal(r.response.status, "413 Request Entity Too Large")
+        assert r.response.status == "413 Request Entity Too Large"
 
     def test_non_utf8_data_posted(self):
 
@@ -171,7 +167,7 @@ class TestParseFormEncodedData(object):
         with FrescoApp().requestcontext(environ=env) as c:
             request = c.request
             request.charset = 'latin1'
-            assert_equal(request.form['char'], self.char)
+            assert request.form['char'] == self.char
 
     def test_non_utf8_data_getted(self):
 
@@ -181,4 +177,4 @@ class TestParseFormEncodedData(object):
         with FrescoApp().requestcontext(environ=env) as c:
             request = c.request
             request.charset = 'latin1'
-            assert_equal(request.query['char'], self.char)
+            assert request.query['char'] == self.char
